/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 France Telecom R&D
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: MDBTransportDestination.java 20430 2010-10-07 12:49:57Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.cxf.transport.mdb;

import java.util.logging.Logger;

import org.apache.cxf.Bus;
import org.apache.cxf.common.logging.LogUtils;
import org.apache.cxf.interceptor.OneWayProcessorInterceptor;
import org.apache.cxf.message.Message;
import org.apache.cxf.service.model.EndpointInfo;
import org.apache.cxf.transport.AbstractDestination;
import org.apache.cxf.transport.Conduit;
import org.apache.cxf.transport.Destination;
import org.apache.cxf.transport.DestinationWithEndpoint;
import org.apache.cxf.wsdl.EndpointReferenceUtils;

public class MDBTransportDestination extends AbstractDestination implements Destination, DestinationWithEndpoint {

    /**
     * Logger.
     */
    private static final Logger LOG = LogUtils.getL7dLogger(MDBTransportDestination.class);

    private MDBTransportConfiguration mdbTransportConfiguration = null;

    private MDBTransportModeType mode = null;

    public MDBTransportDestination(MDBTransportModeType mode, Bus bus, EndpointInfo endpointInfo,
            MDBTransportConfiguration mdbTransportConfiguration) {
        super(bus, getTargetReference(endpointInfo, bus), endpointInfo);
        this.mdbTransportConfiguration = mdbTransportConfiguration;
        this.mode = mode;
        endpointInfo.setProperty(OneWayProcessorInterceptor.USE_ORIGINAL_THREAD, Boolean.TRUE);
    }

    @Override
    protected Conduit getInbuiltBackChannel(Message message) {
        return new MDBTransportConduit(mode, EndpointReferenceUtils.getAnonymousEndpointReference(), mdbTransportConfiguration);
    }

    @Override
    protected Logger getLogger() {
        return LOG;
    }

    public MDBTransportConfiguration getConfiguration() {
        return mdbTransportConfiguration;
    }

    public MDBTransportModeType getMode() {
        return mode;
    }

}
